@@ -24,10 +24,10 @@ public class LCDRange extends TQWidget {
 		label = new TQLabel(" ", this, "label", 0);
 		label.setAlignment(AlignCenter);
 		
-		connect(slider, SIGNAL("valueChanged(int)"),
-						lcd, SLOT("display(int)"));
-		connect(slider, SIGNAL("valueChanged(int)"),
-						SIGNAL("valueChanged(int)"));
+		connect(slider, TQ_SIGNAL("valueChanged(int)"),
+						lcd, TQ_SLOT("display(int)"));
+		connect(slider, TQ_SIGNAL("valueChanged(int)"),
+						TQ_SIGNAL("valueChanged(int)"));
 
 		setFocusProxy(slider);
 
